# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/indices/v1/components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/indices/v1/components.proto',
  package='systemathics.apis.services.indices.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6systemathics/apis/services/indices/v1/components.proto\x12%systemathics.apis.services.indices.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\'\n\x11\x43omponentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"Z\n\x12\x43omponentsResponse\x12\x44\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.indices.v1.Component\"]\n\tComponent\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x32\x97\x01\n\x11\x43omponentsService\x12\x81\x01\n\nComponents\x12\x38.systemathics.apis.services.indices.v1.ComponentsRequest\x1a\x39.systemathics.apis.services.indices.v1.ComponentsResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_COMPONENTSREQUEST = _descriptor.Descriptor(
  name='ComponentsRequest',
  full_name='systemathics.apis.services.indices.v1.ComponentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.indices.v1.ComponentsRequest.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=263,
)


_COMPONENTSRESPONSE = _descriptor.Descriptor(
  name='ComponentsResponse',
  full_name='systemathics.apis.services.indices.v1.ComponentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='systemathics.apis.services.indices.v1.ComponentsResponse.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=265,
  serialized_end=355,
)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='systemathics.apis.services.indices.v1.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.indices.v1.Component.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='systemathics.apis.services.indices.v1.Component.weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=450,
)

_COMPONENTSRESPONSE.fields_by_name['components'].message_type = _COMPONENT
_COMPONENT.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
DESCRIPTOR.message_types_by_name['ComponentsRequest'] = _COMPONENTSREQUEST
DESCRIPTOR.message_types_by_name['ComponentsResponse'] = _COMPONENTSRESPONSE
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ComponentsRequest = _reflection.GeneratedProtocolMessageType('ComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSREQUEST,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsRequest)
  })
_sym_db.RegisterMessage(ComponentsRequest)

ComponentsResponse = _reflection.GeneratedProtocolMessageType('ComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSRESPONSE,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.ComponentsResponse)
  })
_sym_db.RegisterMessage(ComponentsResponse)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENT,
  '__module__' : 'systemathics.apis.services.indices.v1.components_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.indices.v1.Component)
  })
_sym_db.RegisterMessage(Component)



_COMPONENTSSERVICE = _descriptor.ServiceDescriptor(
  name='ComponentsService',
  full_name='systemathics.apis.services.indices.v1.ComponentsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=453,
  serialized_end=604,
  methods=[
  _descriptor.MethodDescriptor(
    name='Components',
    full_name='systemathics.apis.services.indices.v1.ComponentsService.Components',
    index=0,
    containing_service=None,
    input_type=_COMPONENTSREQUEST,
    output_type=_COMPONENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMPONENTSSERVICE)

DESCRIPTOR.services_by_name['ComponentsService'] = _COMPONENTSSERVICE

# @@protoc_insertion_point(module_scope)
